Learn R Programming

lsirm12pl (version 2.0.0)

lsirm.formula: Formula function for LSIRM

Description

lsirm.formula is formula object.

Usage

# S3 method for formula
lsirm(formula, ...)

Arguments

formula

The form of formula is lsirm(A ~ <term 1>(<term 2>, <term 3> ...)), where A is an item response matrix to be analyzed, <term1> is the model you want to fit and has one of the following values: "lsirm1pl", "lsirm2pl", "lsirmgrm", and "lsirmgrm2pl"., and <term 2>, <term 3>, etc., are each option for the model.

...

Additional arguments for the corresponding function.