lsirm.formula is formula object.
# S3 method for formula
lsirm(formula, ...)The form of formula is lsirm(A ~ <term 1>(<term 2>, <term 3> ...)), where A is binary or continuous item response matrix to be analyzed, <term1> is the model you want to fit and has one of the following values: "lsirm1pl" and "lsirm2pl"., and <term 2>, <term 3>, etc., are each option for the model.
Additional arguments for the corresponding function.